Dense Layers
=========================

This module provides specialized dense layer implementations for concept-based models.

.. currentmodule:: torch_concepts.nn

Summary
-------

**Dense Layer Classes**

.. autosummary::
   :toctree: generated
   :nosignatures:

   Dense
   MLP
   ResidualMLP


Class Documentation
-------------------

.. autoclass:: Dense
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: MLP
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ResidualMLP
   :members:
   :undoc-members:
   :show-inheritance:
